summaryrefslogtreecommitdiff
path: root/src/roster.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/roster.py')
-rw-r--r--src/roster.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/roster.py b/src/roster.py
index d18a41c4..d2b99cef 100644
--- a/src/roster.py
+++ b/src/roster.py
@@ -19,18 +19,18 @@ from roster_sorting import SORTING_METHODS, GROUP_SORTING_METHODS
from os import path as p
from datetime import datetime
from common import safeJID
-from sleekxmpp.exceptions import IqError, IqTimeout
+from slixmpp.exceptions import IqError, IqTimeout
class Roster(object):
"""
- The proxy class to get the roster from SleekXMPP.
+ The proxy class to get the roster from slixmpp.
Caches Contact and RosterGroup objects.
"""
def __init__(self):
"""
node: the RosterSingle from SleekXMPP
"""
self.__node = None
self.contact_filter = None # A tuple(function, *args)
@@ -111,7 +111,7 @@ class Roster(object):
return self.contacts[jid]
def set_node(self, value):
"""Set the SleekXMPP RosterSingle for our roster"""
self.__node = value
def get_groups(self, sort=''):
@@ -19,18 +19,18 @@ from roster_sorting import SORTING_METHODS, GROUP_SORTING_METHODS
def __init__(self):
"""
- node: the RosterSingle from SleekXMPP
+ node: the RosterSingle from slixmpp
"""
self.__node = None
@@ -111,7 +111,7 @@ class Roster(object):
return self.contacts[jid]
def set_node(self, value):
- """Set the SleekXMPP RosterSingle for our roster"""
+ """Set the slixmpp RosterSingle for our roster"""
self.__node = value
def get_groups(self, sort=''):